@@ -6,6 +6,11 @@
 #' @param group the map group to which the popups should be added.
 #' @param width the width of the image(s) in pixels.
 #' @param height the height of the image(s) in pixels.
+#' @param tooltip logical, whether to show image(s) as popup(s) (on click) or
+#'   tooltip(s) (on hover).
+#' @param ... additional options passed on to the JavaScript creator function.
+#'   See \url{https://leafletjs.com/reference-1.7.1.html#popup} &
+#'   \url{https://leafletjs.com/reference-1.7.1.html#tooltip} for details.
 #'
 #' @return
 #' A \code{leaflet} map.
@@ -16,6 +21,7 @@
 #' ### one image
 #' library(leaflet)
 #' library(sf)
+#' library(lattice)
 #'
 #' pnt = st_as_sf(data.frame(x = 174.764474, y = -36.877245),
 #'                 coords = c("x", "y"),
@@ -57,7 +63,13 @@
 #' @export addPopupImages
 #' @name addPopupImages
 #' @rdname addPopupImages
-addPopupImages = function(map, image, group, width = NULL, height = NULL) {
+addPopupImages = function(map,
+                          image,
+                          group,
+                          width = NULL,
+                          height = NULL,
+                          tooltip = FALSE,
+                          ...) {
 
   drs = createTempFolder("images")
 
@@ -103,7 +115,14 @@ addPopupImages = function(map, image, group, width = NULL, height = NULL) {
       height = height
     }
 
-    return(list(nm = nm, width = width, height = height, src = src))
+    return(
+      list(
+        nm = nm
+        , width = width
+        , height = height
+        , src = src
+      )
+    )
 
   })
 
@@ -148,6 +167,13 @@ addPopupImages = function(map, image, group, width = NULL, height = NULL) {
   }
   map$dependencies = map$dependencies[!duplicated(map$dependencies)]
 
+  dotlist = utils::modifyList(
+    list(
+      "maxWidth" = 2000
+    )
+    , list(...)
+  )
+
   leaflet::invokeMethod(
     map,
     leaflet::getMapData(map),
@@ -157,6 +183,8 @@ addPopupImages = function(map, image, group, width = NULL, height = NULL) {
     width,
     height,
     src,
-    as.list(name)
+    as.list(name),
+    tooltip,
+    dotlist
   )
 }
